package llmapi

import (
	"context"
	"gralias/models"
	"log/slog"
	"os"
)

var log *slog.Logger

func init() {
	log = slog.New(slog.NewJSONHandler(os.Stderr, &slog.HandlerOptions{
		Level:     slog.LevelDebug,
		AddSource: true,
	}))
}

// updateStatsOnGameOver updates stats for all players in a room when a game ends.
func updateStatsOnGameOver(ctx context.Context, room *models.Room) {
	// Get all players in the room
	players, err := repo.PlayerListByRoom(ctx, room.ID)
	if err != nil {
		log.Error("failed to list players by room for stats update", "room_id", room.ID, "error", err)
		return
	}

	for _, player := range players {
		if player.IsBot {
			continue
		}

		stats, err := repo.GetPlayerStats(ctx, player.Username)
		if err != nil {
			log.Error("failed to get player stats for game over update", "username", player.Username, "error", err)
			continue
		}

		stats.GamesPlayed++
		if player.Team == room.TeamWon {
			stats.GamesWon++
		} else {
			stats.GamesLost++
		}

		if player.Role == models.UserRoleMime {
			stats.PlayedAsMime++
			if stats.PlayedAsMime > 0 {
				gamesWonAsMime := stats.MimeWinrate * float32(stats.PlayedAsMime-1)
				if player.Team == room.TeamWon {
					gamesWonAsMime++
				}
				stats.MimeWinrate = gamesWonAsMime / float32(stats.PlayedAsMime)
			}
		} else if player.Role == models.UserRoleGuesser {
			stats.PlayedAsGuesser++
			if stats.PlayedAsGuesser > 0 {
				gamesWonAsGuesser := stats.GuesserWinrate * float32(stats.PlayedAsGuesser-1)
				if player.Team == room.TeamWon {
					gamesWonAsGuesser++
				}
				stats.GuesserWinrate = gamesWonAsGuesser / float32(stats.PlayedAsGuesser)
			}
		}

		if err := repo.UpdatePlayerStats(ctx, stats); err != nil {
			log.Error("failed to update player stats on game over", "username", player.Username, "error", err)
		}
	}
}
